/*
 * register.h
 *
 *  Created on: 17 avr. 2023
 *      Author: sylvain
 */

#ifndef INC_REGISTER_H_
#define INC_REGISTER_H_

/* Includes ------------------------------------------------------------------*/
#include "stm32l0xx_ll_adc.h"
#include "stm32l0xx_ll_i2c.h"
#include "stm32l0xx_ll_crs.h"
#include "stm32l0xx_ll_rcc.h"
#include "stm32l0xx_ll_bus.h"
#include "stm32l0xx_ll_system.h"
#include "stm32l0xx_ll_exti.h"
#include "stm32l0xx_ll_cortex.h"
#include "stm32l0xx_ll_utils.h"
#include "stm32l0xx_ll_pwr.h"
#include "stm32l0xx_ll_dma.h"
#include "stm32l0xx_ll_spi.h"
#include "stm32l0xx_ll_tim.h"
#include "stm32l0xx_ll_usart.h"
#include "stm32l0xx_ll_gpio.h"

#include "main.h"
#include "stdbool.h"

/* Inputs ---------------------------------------------------------------------*/
#define mREG_ADC_TEMP_Pin LL_GPIO_PIN_0
#define mREG_ADC_TEMP_GPIO_Port GPIOA
#define mREG_VCP_TX_Pin LL_GPIO_PIN_2
#define mREG_VCP_TX_GPIO_Port GPIOA
#define mREG_ENC2_Pin LL_GPIO_PIN_3
#define mREG_ENC2_GPIO_Port GPIOA
#define mREG_ENC2_EXTI_IRQn EXTI2_3_IRQn
#define mREG_ENC1_Pin LL_GPIO_PIN_0
#define mREG_ENC1_GPIO_Port GPIOB
#define mREG_ENC1_EXTI_IRQn EXTI0_1_IRQn
#define mREG_LED_Pin LL_GPIO_PIN_1
#define mREG_LED_GPIO_Port GPIOB
#define mREG_PWM_HEATER_Pin LL_GPIO_PIN_8
#define mREG_PWM_HEATER_GPIO_Port GPIOA
#define mREG_ENC_SW_Pin LL_GPIO_PIN_9
#define mREG_ENC_SW_GPIO_Port GPIOA
#define mREG_STANDBY_SW_Pin LL_GPIO_PIN_12
#define mREG_STANDBY_SW_GPIO_Port GPIOA
#define mREG_TMS_Pin LL_GPIO_PIN_13
#define mREG_TMS_GPIO_Port GPIOA
#define mREG_mREG_TCK_Pin LL_GPIO_PIN_14
#define mREG_TCK_GPIO_Port GPIOA
#define mREG_VCP_RX_Pin LL_GPIO_PIN_15
#define mREG_VCP_RX_GPIO_Port GPIOA
#define mREG_LED_BLUE_Pin LL_GPIO_PIN_3
#define mREG_LED_BLUE_GPIO_Port GPIOB
#define mREG_DISPLAY_LATCH_Pin LL_GPIO_PIN_4
#define mREG_DISPLAY_LATCH_GPIO_Port GPIOB
#define mREG_DISPLAY_K1_Pin LL_GPIO_PIN_6
#define mREG_DISPLAY_K1_GPIO_Port GPIOB
#define mREG_DISPLAY_K2_Pin LL_GPIO_PIN_7
#define mREG_DISPLAY_K2_GPIO_Port GPIOB
#define mREG_DISPLAY_K3_Pin LL_GPIO_PIN_11
#define mREG_DISPLAY_K3_GPIO_Port GPIOA

/* Inputs --------------------------------------------------------*/
#define mREGInputsENC1ActiveState    	(true)
#define mREGInputsENC1GetState()     	(bool)(LL_GPIO_IsInputPinSet(mREG_ENC1_GPIO_Port, mREG_ENC1_Pin) == mREGInputsENC1ActiveState)

#define mREGInputsENC2ActiveState    	(true)
#define mREGInputsENC2GetState()     	(bool)(LL_GPIO_IsInputPinSet(mREG_ENC2_GPIO_Port, mREG_ENC2_Pin) == mREGInputsENC2ActiveState)

#define mREGInputsSWActiveState      	(false)
#define mREGInputsSWGetState()			(bool)(LL_GPIO_IsInputPinSet(mREG_ENC_SW_GPIO_Port, mREG_ENC_SW_Pin) == mREGInputsSWActiveState)

/* Outputs --------------------------------------------------------*/
#define mREGOutputsDisplayK1SetState()		(LL_GPIO_SetOutputPin(mREG_DISPLAY_K1_GPIO_Port, mREG_DISPLAY_K1_Pin))
#define mREGOutputsDisplayK1ResetState()	(LL_GPIO_ResetOutputPin(mREG_DISPLAY_K1_GPIO_Port, mREG_DISPLAY_K1_Pin))

#define mREGOutputsDisplayK2SetState()		(LL_GPIO_SetOutputPin(mREG_DISPLAY_K2_GPIO_Port, mREG_DISPLAY_K2_Pin))
#define mREGOutputsDisplayK2ResetState()	(LL_GPIO_ResetOutputPin(mREG_DISPLAY_K2_GPIO_Port, mREG_DISPLAY_K2_Pin))

#define mREGOutputsDisplayK3SetState()		(LL_GPIO_SetOutputPin(mREG_DISPLAY_K3_GPIO_Port, mREG_DISPLAY_K3_Pin))
#define mREGOutputsDisplayK3ResetState()	(LL_GPIO_ResetOutputPin(mREG_DISPLAY_K3_GPIO_Port, mREG_DISPLAY_K3_Pin))

#define mREGOutputsDisplayLATCHSetState()	(LL_GPIO_SetOutputPin(mREG_DISPLAY_LATCH_GPIO_Port, mREG_DISPLAY_LATCH_Pin))
#define mREGOutputsDisplayLATCHResetState()	(LL_GPIO_ResetOutputPin(mREG_DISPLAY_LATCH_GPIO_Port, mREG_DISPLAY_LATCH_Pin))

/* SPI --------------------------------------------------------*/
#define mREGSpi1Enable()					(LL_SPI_Enable(SPI1))
#define mREGSpi1Disable()					(LL_SPI_Disable(SPI1))
#define mREGSpi1InterruptRxEnable()			(LL_SPI_EnableIT_RXNE(SPI1))
#define mREGSpi1InterruptRxDisable()		(LL_SPI_DisableIT_RXNE(SPI1))
#define mREGSpi1SendFrame(frame) 			(LL_SPI_TransmitData8(SPI1, frame))
#define mREGSpi1ReadFrame()					(LL_SPI_ReceiveData8(SPI1))

/* External interrupts --------------------------------------------------------*/
// ENC1 : EXTI0
#define mREGInputsENC1ExtiLine			LL_EXTI_LINE_0
#define mREGInputsENC1ExtiEnableIT() 	(LL_EXTI_EnableIT_0_31(mREGInputsENC1ExtiLine))
#define mREGInputsENC1ExtiClearFlag()	(LL_EXTI_ClearFlag_0_31(mREGInputsENC1ExtiLine))

// ENC2 : EXTI3
#define mREGInputsENC2ExtiLine			LL_EXTI_LINE_3
#define mREGInputsENC2ExtiEnableIT() 	(LL_EXTI_EnableIT_0_31(mREGInputsENC1ExtiLine))
#define mREGInputsENC2ExtiClearFlag()	(LL_EXTI_ClearFlag_0_31(mREGInputsENC1ExtiLine))

/* ADC --------------------------------------------------------*/
#define mREGAdcHandle					ADC1
#define mREGAdcStartConversion()		(LL_ADC_REG_StartConversion(mREGAdcHandle))
#define mREGAdcStopConversion()			(LL_ADC_REG_StopConversion(mREGAdcHandle))
#define mREGAdcReadValue()				(LL_ADC_REG_ReadConversionData12(mREGAdcHandle))

/* PWM --------------------------------------------------------*/
#define mREGPwmSetCompareValue(val) 	(LL_TIM_OC_SetCompareCH1(TIM2, (uint32_t)val))

#endif /* INC_REGISTER_H_ */
